@@ -6,9 +6,9 @@ Coro::Debug - various functions that help debugging Coro programs
 
  use Coro::Debug;
 
- our $server = new_server Coro::Debug path => "/tmp/socketpath";
+ our $server = new_unix_server Coro::Debug path => "/tmp/socketpath";
 
- $ socat readline: unix:/tmp/socketpath
+ $ socat readline unix:/tmp/socketpath
 
 =head1 DESCRIPTION
 
@@ -285,7 +285,10 @@ sub command($) {
    } elsif ($cmd =~ /^bt\s+(\d+)$/) {
       if (my $coro = find_coro $1) {
          my $bt;
-         Coro::State::call ($coro, sub { $bt = Carp::longmess "coroutine is" });
+         Coro::State::call ($coro, sub {
+            local $Carp::CarpLevel = 2;
+            $bt = eval { Carp::longmess "coroutine is" } || "$@";
+         });
          if ($bt) {
             print $bt;
          } else {
